@@ -1,9 +1,4 @@
-import random
 import numpy as np
-import struct
-import os
-import numpy as np
-import matplotlib.pyplot as plt
 import scipy
 
 __all__ = ['lags_matrix','covariance_matrix', 'conv_matrix']
